@@ -27,7 +27,10 @@ async def gather(hub, profiles):
               - channel2
     """
     sub_profiles = {}
-    for profile, ctx, in profiles.get("pika", {}).items():
+    for (
+        profile,
+        ctx,
+    ) in profiles.get("pika", {}).items():
         sub_profiles[profile] = {
             "connected": False,
             "channels": ctx.pop("ingress_channels", []),
